Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1604)

Unified Diff: chrome/browser/sync/glue/model_associator.h

Issue 292008: Fix ProfileSyncService unit test. (Closed)
Patch Set: Created 11 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/sync/glue/http_bridge.h ('k') | chrome/browser/sync/glue/model_associator.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/sync/glue/model_associator.h
diff --git a/chrome/browser/sync/glue/model_associator.h b/chrome/browser/sync/glue/model_associator.h
index d0db9113d0944d32a62cb3ec0e30349565078227..dc6aabab4040814675bac1425cf8bd166a40894e 100644
--- a/chrome/browser/sync/glue/model_associator.h
+++ b/chrome/browser/sync/glue/model_associator.h
@@ -4,8 +4,8 @@
#if defined(BROWSER_SYNC)
-#ifndef CHROME_BROWSER_SYNC_GLUE_MODEL_ASSOCATOR_H_
-#define CHROME_BROWSER_SYNC_GLUE_MODEL_ASSOCATOR_H_
+#ifndef CHROME_BROWSER_SYNC_GLUE_MODEL_ASSOCIATOR_H_
+#define CHROME_BROWSER_SYNC_GLUE_MODEL_ASSOCIATOR_H_
#include <map>
#include <set>
@@ -30,17 +30,17 @@ namespace browser_sync {
class ChangeProcessor;
-// Contains all model assocation related logic:
+// Contains all model association related logic:
// * Algorithm to associate bookmark model and sync model.
// * Methods to get a bookmark node for a given sync node and vice versa.
// * Persisting model assocations and loading them back.
class ModelAssociator
: public base::RefCountedThreadSafe<ModelAssociator> {
public:
explicit ModelAssociator(ProfileSyncService* sync_service);
virtual ~ModelAssociator() { }
// Clears all assocations.
void ClearAll();
// Returns sync id for the given bookmark node id.
@@ -96,21 +96,21 @@ class ModelAssociator
private:
typedef std::map<int64, int64> BookmarkIdToSyncIdMap;
typedef std::map<int64, int64> SyncIdToBookmarkIdMap;
- typedef std::set<int64> DirtyAssocationsSyncIds;
+ typedef std::set<int64> DirtyAssociationsSyncIds;
- // Posts a task to persist dirty assocations.
+ // Posts a task to persist dirty associations.
void PostPersistAssociationsTask();
// Persists all dirty assocations.
void PersistAssociations();
// Loads the persisted assocations into in-memory maps.
// If the persisted associations are out-of-date due to some reason, returns
- // false; otehrwise returns true.
+ // false; otherwise returns true.
bool LoadAssociations();
// Matches up the bookmark model and the sync model to build model
- // assocations.
- bool BuildAssocations();
+ // associations.
+ bool BuildAssociations();
// Associate a top-level node of the bookmark model with a permanent node in
// the sync domain. Such permanent nodes are identified by a tag that is
@@ -128,7 +128,7 @@ class ModelAssociator
BookmarkIdToSyncIdMap id_map_;
SyncIdToBookmarkIdMap id_map_inverse_;
// Stores sync ids for dirty associations.
- DirtyAssocationsSyncIds dirty_assocations_sync_ids_;
+ DirtyAssociationsSyncIds dirty_associations_sync_ids_;
// Indicates whether there is already a pending task to persist dirty model
// associations.
@@ -139,5 +139,5 @@ class ModelAssociator
} // namespace browser_sync
-#endif // CHROME_BROWSER_SYNC_GLUE_MODEL_ASSOCATOR_H_
+#endif // CHROME_BROWSER_SYNC_GLUE_MODEL_ASSOCIATOR_H_
#endif // defined(BROWSER_SYNC)
« no previous file with comments | « chrome/browser/sync/glue/http_bridge.h ('k') | chrome/browser/sync/glue/model_associator.cc » ('j') | no next file with comments »
@@ -30,17 +30,17 @@ namespace browser_sync {
// * Algorithm to associate bookmark model and sync model.
// * Methods to get a bookmark node for a given sync node and vice versa.
-// * Persisting model assocations and loading them back.
+// * Persisting model associations and loading them back.
class ModelAssociator
: public base::RefCountedThreadSafe<ModelAssociator> {
@@ -30,17 +30,17 @@ namespace browser_sync {
explicit ModelAssociator(ProfileSyncService* sync_service);
virtual ~ModelAssociator() { }
- // Clears all assocations.
+ // Clears all associations.
void ClearAll();
// Returns sync id for the given bookmark node id.
@@ -96,21 +96,21 @@ class ModelAssociator
void PostPersistAssociationsTask();
- // Persists all dirty assocations.
+ // Persists all dirty associations.
void PersistAssociations();
@@ -96,21 +96,21 @@ class ModelAssociator
void PersistAssociations();
- // Loads the persisted assocations into in-memory maps.
+ // Loads the persisted associations into in-memory maps.
// If the persisted associations are out-of-date due to some reason, returns

Powered by Google App Engine
This is Rietveld 408576698